# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023BurrHole2(str, Enum):
    """
    Enum class for Burr hole 2.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    STEREOTAXIC_INJECTION = 'Stereotaxic Injection'
    SPINAL_INJECTION = 'Spinal Injection'
    FIBER_IMPLANT = 'Fiber Implant'
    STEREOTAXIC_INJECTION__F = 'Stereotaxic Injection & Fiber Implant'
    INJECTION = 'Injection'
    INJECTION_FIBER_IMPLANT = 'Injection & Fiber Implant'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023BurrHole2 from a JSON string"""
        return cls(json.loads(json_str))


